// Copyright 2013 The Flutter Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// Autogenerated from Pigeon (v17.1.2), do not edit directly.
// See also: https://pub.dev/packages/pigeon

package io.flutter.plugins.inapppurchase;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.CLASS;

import android.util.Log;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MessageCodec;
import io.flutter.plugin.common.StandardMessageCodec;
import java.io.ByteArrayOutputStream;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/** Generated class from Pigeon. */
@SuppressWarnings({"unused", "unchecked", "CodeBlock2Expr", "RedundantSuppression", "serial"})
public class Messages {

  /** Error class for passing custom error details to Flutter via a thrown PlatformException. */
  public static class FlutterError extends RuntimeException {

    /** The error code. */
    public final String code;

    /** The error details. Must be a datatype supported by the api codec. */
    public final Object details;

    public FlutterError(@NonNull String code, @Nullable String message, @Nullable Object details) {
      super(message);
      this.code = code;
      this.details = details;
    }
  }

  @NonNull
  protected static ArrayList<Object> wrapError(@NonNull Throwable exception) {
    ArrayList<Object> errorList = new ArrayList<Object>(3);
    if (exception instanceof FlutterError) {
      FlutterError error = (FlutterError) exception;
      errorList.add(error.code);
      errorList.add(error.getMessage());
      errorList.add(error.details);
    } else {
      errorList.add(exception.toString());
      errorList.add(exception.getClass().getSimpleName());
      errorList.add(
          "Cause: " + exception.getCause() + ", Stacktrace: " + Log.getStackTraceString(exception));
    }
    return errorList;
  }

  @NonNull
  protected static FlutterError createConnectionError(@NonNull String channelName) {
    return new FlutterError(
        "channel-error", "Unable to establish connection on channel: " + channelName + ".", "");
  }

  @Target(METHOD)
  @Retention(CLASS)
  @interface CanIgnoreReturnValue {}

  /** Pigeon version of Java BillingClient.ProductType. */
  public enum PlatformProductType {
    INAPP(0),
    SUBS(1);

    final int index;

    private PlatformProductType(final int index) {
      this.index = index;
    }
  }

  /** Pigeon version of billing_client_wrapper.dart's BillingChoiceMode. */
  public enum PlatformBillingChoiceMode {
    /**
     * Billing through google play.
     *
     * <p>Default state.
     */
    PLAY_BILLING_ONLY(0),
    /** Billing through app provided flow. */
    ALTERNATIVE_BILLING_ONLY(1),
    /** Users can choose Play billing or alternative billing. */
    USER_CHOICE_BILLING(2);

    final int index;

    private PlatformBillingChoiceMode(final int index) {
      this.index = index;
    }
  }

  /**
   * Pigeon version of Java Product.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformProduct {
    private @NonNull String productId;

    public @NonNull String getProductId() {
      return productId;
    }

    public void setProductId(@NonNull String setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"productId\" is null.");
      }
      this.productId = setterArg;
    }

    private @NonNull PlatformProductType productType;

    public @NonNull PlatformProductType getProductType() {
      return productType;
    }

    public void setProductType(@NonNull PlatformProductType setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"productType\" is null.");
      }
      this.productType = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformProduct() {}

    public static final class Builder {

      private @Nullable String productId;

      @CanIgnoreReturnValue
      public @NonNull Builder setProductId(@NonNull String setterArg) {
        this.productId = setterArg;
        return this;
      }

      private @Nullable PlatformProductType productType;

      @CanIgnoreReturnValue
      public @NonNull Builder setProductType(@NonNull PlatformProductType setterArg) {
        this.productType = setterArg;
        return this;
      }

      public @NonNull PlatformProduct build() {
        PlatformProduct pigeonReturn = new PlatformProduct();
        pigeonReturn.setProductId(productId);
        pigeonReturn.setProductType(productType);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add(productId);
      toListResult.add(productType == null ? null : productType.index);
      return toListResult;
    }

    static @NonNull PlatformProduct fromList(@NonNull ArrayList<Object> list) {
      PlatformProduct pigeonResult = new PlatformProduct();
      Object productId = list.get(0);
      pigeonResult.setProductId((String) productId);
      Object productType = list.get(1);
      pigeonResult.setProductType(PlatformProductType.values()[(int) productType]);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of Java BillingResult.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformBillingResult {
    private @NonNull Long responseCode;

    public @NonNull Long getResponseCode() {
      return responseCode;
    }

    public void setResponseCode(@NonNull Long setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"responseCode\" is null.");
      }
      this.responseCode = setterArg;
    }

    private @NonNull String debugMessage;

    public @NonNull String getDebugMessage() {
      return debugMessage;
    }

    public void setDebugMessage(@NonNull String setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"debugMessage\" is null.");
      }
      this.debugMessage = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformBillingResult() {}

    public static final class Builder {

      private @Nullable Long responseCode;

      @CanIgnoreReturnValue
      public @NonNull Builder setResponseCode(@NonNull Long setterArg) {
        this.responseCode = setterArg;
        return this;
      }

      private @Nullable String debugMessage;

      @CanIgnoreReturnValue
      public @NonNull Builder setDebugMessage(@NonNull String setterArg) {
        this.debugMessage = setterArg;
        return this;
      }

      public @NonNull PlatformBillingResult build() {
        PlatformBillingResult pigeonReturn = new PlatformBillingResult();
        pigeonReturn.setResponseCode(responseCode);
        pigeonReturn.setDebugMessage(debugMessage);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add(responseCode);
      toListResult.add(debugMessage);
      return toListResult;
    }

    static @NonNull PlatformBillingResult fromList(@NonNull ArrayList<Object> list) {
      PlatformBillingResult pigeonResult = new PlatformBillingResult();
      Object responseCode = list.get(0);
      pigeonResult.setResponseCode(
          (responseCode == null)
              ? null
              : ((responseCode instanceof Integer) ? (Integer) responseCode : (Long) responseCode));
      Object debugMessage = list.get(1);
      pigeonResult.setDebugMessage((String) debugMessage);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of ProductDetailsResponseWrapper, which contains the components of the Java
   * ProductDetailsResponseListener callback.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformProductDetailsResponse {
    private @NonNull PlatformBillingResult billingResult;

    public @NonNull PlatformBillingResult getBillingResult() {
      return billingResult;
    }

    public void setBillingResult(@NonNull PlatformBillingResult setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"billingResult\" is null.");
      }
      this.billingResult = setterArg;
    }

    /**
     * A JSON-compatible list of details, where each entry in the list is a Map<String, Object?>
     * JSON encoding of the product details.
     */
    private @NonNull List<Object> productDetailsJsonList;

    public @NonNull List<Object> getProductDetailsJsonList() {
      return productDetailsJsonList;
    }

    public void setProductDetailsJsonList(@NonNull List<Object> setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"productDetailsJsonList\" is null.");
      }
      this.productDetailsJsonList = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformProductDetailsResponse() {}

    public static final class Builder {

      private @Nullable PlatformBillingResult billingResult;

      @CanIgnoreReturnValue
      public @NonNull Builder setBillingResult(@NonNull PlatformBillingResult setterArg) {
        this.billingResult = setterArg;
        return this;
      }

      private @Nullable List<Object> productDetailsJsonList;

      @CanIgnoreReturnValue
      public @NonNull Builder setProductDetailsJsonList(@NonNull List<Object> setterArg) {
        this.productDetailsJsonList = setterArg;
        return this;
      }

      public @NonNull PlatformProductDetailsResponse build() {
        PlatformProductDetailsResponse pigeonReturn = new PlatformProductDetailsResponse();
        pigeonReturn.setBillingResult(billingResult);
        pigeonReturn.setProductDetailsJsonList(productDetailsJsonList);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add((billingResult == null) ? null : billingResult.toList());
      toListResult.add(productDetailsJsonList);
      return toListResult;
    }

    static @NonNull PlatformProductDetailsResponse fromList(@NonNull ArrayList<Object> list) {
      PlatformProductDetailsResponse pigeonResult = new PlatformProductDetailsResponse();
      Object billingResult = list.get(0);
      pigeonResult.setBillingResult(
          (billingResult == null)
              ? null
              : PlatformBillingResult.fromList((ArrayList<Object>) billingResult));
      Object productDetailsJsonList = list.get(1);
      pigeonResult.setProductDetailsJsonList((List<Object>) productDetailsJsonList);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of AlternativeBillingOnlyReportingDetailsWrapper, which contains the components
   * of the Java AlternativeBillingOnlyReportingDetailsListener callback.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformAlternativeBillingOnlyReportingDetailsResponse {
    private @NonNull PlatformBillingResult billingResult;

    public @NonNull PlatformBillingResult getBillingResult() {
      return billingResult;
    }

    public void setBillingResult(@NonNull PlatformBillingResult setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"billingResult\" is null.");
      }
      this.billingResult = setterArg;
    }

    private @NonNull String externalTransactionToken;

    public @NonNull String getExternalTransactionToken() {
      return externalTransactionToken;
    }

    public void setExternalTransactionToken(@NonNull String setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"externalTransactionToken\" is null.");
      }
      this.externalTransactionToken = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformAlternativeBillingOnlyReportingDetailsResponse() {}

    public static final class Builder {

      private @Nullable PlatformBillingResult billingResult;

      @CanIgnoreReturnValue
      public @NonNull Builder setBillingResult(@NonNull PlatformBillingResult setterArg) {
        this.billingResult = setterArg;
        return this;
      }

      private @Nullable String externalTransactionToken;

      @CanIgnoreReturnValue
      public @NonNull Builder setExternalTransactionToken(@NonNull String setterArg) {
        this.externalTransactionToken = setterArg;
        return this;
      }

      public @NonNull PlatformAlternativeBillingOnlyReportingDetailsResponse build() {
        PlatformAlternativeBillingOnlyReportingDetailsResponse pigeonReturn =
            new PlatformAlternativeBillingOnlyReportingDetailsResponse();
        pigeonReturn.setBillingResult(billingResult);
        pigeonReturn.setExternalTransactionToken(externalTransactionToken);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add((billingResult == null) ? null : billingResult.toList());
      toListResult.add(externalTransactionToken);
      return toListResult;
    }

    static @NonNull PlatformAlternativeBillingOnlyReportingDetailsResponse fromList(
        @NonNull ArrayList<Object> list) {
      PlatformAlternativeBillingOnlyReportingDetailsResponse pigeonResult =
          new PlatformAlternativeBillingOnlyReportingDetailsResponse();
      Object billingResult = list.get(0);
      pigeonResult.setBillingResult(
          (billingResult == null)
              ? null
              : PlatformBillingResult.fromList((ArrayList<Object>) billingResult));
      Object externalTransactionToken = list.get(1);
      pigeonResult.setExternalTransactionToken((String) externalTransactionToken);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of BillingConfigWrapper, which contains the components of the Java
   * BillingConfigResponseListener callback.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformBillingConfigResponse {
    private @NonNull PlatformBillingResult billingResult;

    public @NonNull PlatformBillingResult getBillingResult() {
      return billingResult;
    }

    public void setBillingResult(@NonNull PlatformBillingResult setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"billingResult\" is null.");
      }
      this.billingResult = setterArg;
    }

    private @NonNull String countryCode;

    public @NonNull String getCountryCode() {
      return countryCode;
    }

    public void setCountryCode(@NonNull String setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"countryCode\" is null.");
      }
      this.countryCode = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformBillingConfigResponse() {}

    public static final class Builder {

      private @Nullable PlatformBillingResult billingResult;

      @CanIgnoreReturnValue
      public @NonNull Builder setBillingResult(@NonNull PlatformBillingResult setterArg) {
        this.billingResult = setterArg;
        return this;
      }

      private @Nullable String countryCode;

      @CanIgnoreReturnValue
      public @NonNull Builder setCountryCode(@NonNull String setterArg) {
        this.countryCode = setterArg;
        return this;
      }

      public @NonNull PlatformBillingConfigResponse build() {
        PlatformBillingConfigResponse pigeonReturn = new PlatformBillingConfigResponse();
        pigeonReturn.setBillingResult(billingResult);
        pigeonReturn.setCountryCode(countryCode);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add((billingResult == null) ? null : billingResult.toList());
      toListResult.add(countryCode);
      return toListResult;
    }

    static @NonNull PlatformBillingConfigResponse fromList(@NonNull ArrayList<Object> list) {
      PlatformBillingConfigResponse pigeonResult = new PlatformBillingConfigResponse();
      Object billingResult = list.get(0);
      pigeonResult.setBillingResult(
          (billingResult == null)
              ? null
              : PlatformBillingResult.fromList((ArrayList<Object>) billingResult));
      Object countryCode = list.get(1);
      pigeonResult.setCountryCode((String) countryCode);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of Java BillingFlowParams.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformBillingFlowParams {
    private @NonNull String product;

    public @NonNull String getProduct() {
      return product;
    }

    public void setProduct(@NonNull String setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"product\" is null.");
      }
      this.product = setterArg;
    }

    private @NonNull Long prorationMode;

    public @NonNull Long getProrationMode() {
      return prorationMode;
    }

    public void setProrationMode(@NonNull Long setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"prorationMode\" is null.");
      }
      this.prorationMode = setterArg;
    }

    private @Nullable String offerToken;

    public @Nullable String getOfferToken() {
      return offerToken;
    }

    public void setOfferToken(@Nullable String setterArg) {
      this.offerToken = setterArg;
    }

    private @Nullable String accountId;

    public @Nullable String getAccountId() {
      return accountId;
    }

    public void setAccountId(@Nullable String setterArg) {
      this.accountId = setterArg;
    }

    private @Nullable String obfuscatedProfileId;

    public @Nullable String getObfuscatedProfileId() {
      return obfuscatedProfileId;
    }

    public void setObfuscatedProfileId(@Nullable String setterArg) {
      this.obfuscatedProfileId = setterArg;
    }

    private @Nullable String oldProduct;

    public @Nullable String getOldProduct() {
      return oldProduct;
    }

    public void setOldProduct(@Nullable String setterArg) {
      this.oldProduct = setterArg;
    }

    private @Nullable String purchaseToken;

    public @Nullable String getPurchaseToken() {
      return purchaseToken;
    }

    public void setPurchaseToken(@Nullable String setterArg) {
      this.purchaseToken = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformBillingFlowParams() {}

    public static final class Builder {

      private @Nullable String product;

      @CanIgnoreReturnValue
      public @NonNull Builder setProduct(@NonNull String setterArg) {
        this.product = setterArg;
        return this;
      }

      private @Nullable Long prorationMode;

      @CanIgnoreReturnValue
      public @NonNull Builder setProrationMode(@NonNull Long setterArg) {
        this.prorationMode = setterArg;
        return this;
      }

      private @Nullable String offerToken;

      @CanIgnoreReturnValue
      public @NonNull Builder setOfferToken(@Nullable String setterArg) {
        this.offerToken = setterArg;
        return this;
      }

      private @Nullable String accountId;

      @CanIgnoreReturnValue
      public @NonNull Builder setAccountId(@Nullable String setterArg) {
        this.accountId = setterArg;
        return this;
      }

      private @Nullable String obfuscatedProfileId;

      @CanIgnoreReturnValue
      public @NonNull Builder setObfuscatedProfileId(@Nullable String setterArg) {
        this.obfuscatedProfileId = setterArg;
        return this;
      }

      private @Nullable String oldProduct;

      @CanIgnoreReturnValue
      public @NonNull Builder setOldProduct(@Nullable String setterArg) {
        this.oldProduct = setterArg;
        return this;
      }

      private @Nullable String purchaseToken;

      @CanIgnoreReturnValue
      public @NonNull Builder setPurchaseToken(@Nullable String setterArg) {
        this.purchaseToken = setterArg;
        return this;
      }

      public @NonNull PlatformBillingFlowParams build() {
        PlatformBillingFlowParams pigeonReturn = new PlatformBillingFlowParams();
        pigeonReturn.setProduct(product);
        pigeonReturn.setProrationMode(prorationMode);
        pigeonReturn.setOfferToken(offerToken);
        pigeonReturn.setAccountId(accountId);
        pigeonReturn.setObfuscatedProfileId(obfuscatedProfileId);
        pigeonReturn.setOldProduct(oldProduct);
        pigeonReturn.setPurchaseToken(purchaseToken);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(7);
      toListResult.add(product);
      toListResult.add(prorationMode);
      toListResult.add(offerToken);
      toListResult.add(accountId);
      toListResult.add(obfuscatedProfileId);
      toListResult.add(oldProduct);
      toListResult.add(purchaseToken);
      return toListResult;
    }

    static @NonNull PlatformBillingFlowParams fromList(@NonNull ArrayList<Object> list) {
      PlatformBillingFlowParams pigeonResult = new PlatformBillingFlowParams();
      Object product = list.get(0);
      pigeonResult.setProduct((String) product);
      Object prorationMode = list.get(1);
      pigeonResult.setProrationMode(
          (prorationMode == null)
              ? null
              : ((prorationMode instanceof Integer)
                  ? (Integer) prorationMode
                  : (Long) prorationMode));
      Object offerToken = list.get(2);
      pigeonResult.setOfferToken((String) offerToken);
      Object accountId = list.get(3);
      pigeonResult.setAccountId((String) accountId);
      Object obfuscatedProfileId = list.get(4);
      pigeonResult.setObfuscatedProfileId((String) obfuscatedProfileId);
      Object oldProduct = list.get(5);
      pigeonResult.setOldProduct((String) oldProduct);
      Object purchaseToken = list.get(6);
      pigeonResult.setPurchaseToken((String) purchaseToken);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of PurchasesHistoryResult, which contains the components of the Java
   * PurchaseHistoryResponseListener callback.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformPurchaseHistoryResponse {
    private @NonNull PlatformBillingResult billingResult;

    public @NonNull PlatformBillingResult getBillingResult() {
      return billingResult;
    }

    public void setBillingResult(@NonNull PlatformBillingResult setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"billingResult\" is null.");
      }
      this.billingResult = setterArg;
    }

    /**
     * A JSON-compatible list of purchase history records, where each entry in the list is a
     * Map<String, Object?> JSON encoding of the record.
     */
    private @NonNull List<Object> purchaseHistoryRecordJsonList;

    public @NonNull List<Object> getPurchaseHistoryRecordJsonList() {
      return purchaseHistoryRecordJsonList;
    }

    public void setPurchaseHistoryRecordJsonList(@NonNull List<Object> setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"purchaseHistoryRecordJsonList\" is null.");
      }
      this.purchaseHistoryRecordJsonList = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformPurchaseHistoryResponse() {}

    public static final class Builder {

      private @Nullable PlatformBillingResult billingResult;

      @CanIgnoreReturnValue
      public @NonNull Builder setBillingResult(@NonNull PlatformBillingResult setterArg) {
        this.billingResult = setterArg;
        return this;
      }

      private @Nullable List<Object> purchaseHistoryRecordJsonList;

      @CanIgnoreReturnValue
      public @NonNull Builder setPurchaseHistoryRecordJsonList(@NonNull List<Object> setterArg) {
        this.purchaseHistoryRecordJsonList = setterArg;
        return this;
      }

      public @NonNull PlatformPurchaseHistoryResponse build() {
        PlatformPurchaseHistoryResponse pigeonReturn = new PlatformPurchaseHistoryResponse();
        pigeonReturn.setBillingResult(billingResult);
        pigeonReturn.setPurchaseHistoryRecordJsonList(purchaseHistoryRecordJsonList);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add((billingResult == null) ? null : billingResult.toList());
      toListResult.add(purchaseHistoryRecordJsonList);
      return toListResult;
    }

    static @NonNull PlatformPurchaseHistoryResponse fromList(@NonNull ArrayList<Object> list) {
      PlatformPurchaseHistoryResponse pigeonResult = new PlatformPurchaseHistoryResponse();
      Object billingResult = list.get(0);
      pigeonResult.setBillingResult(
          (billingResult == null)
              ? null
              : PlatformBillingResult.fromList((ArrayList<Object>) billingResult));
      Object purchaseHistoryRecordJsonList = list.get(1);
      pigeonResult.setPurchaseHistoryRecordJsonList((List<Object>) purchaseHistoryRecordJsonList);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of PurchasesResultWrapper, which contains the components of the Java
   * PurchasesResponseListener callback.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformPurchasesResponse {
    private @NonNull PlatformBillingResult billingResult;

    public @NonNull PlatformBillingResult getBillingResult() {
      return billingResult;
    }

    public void setBillingResult(@NonNull PlatformBillingResult setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"billingResult\" is null.");
      }
      this.billingResult = setterArg;
    }

    /**
     * A JSON-compatible list of purchases, where each entry in the list is a Map<String, Object?>
     * JSON encoding of the product details.
     */
    private @NonNull List<Object> purchasesJsonList;

    public @NonNull List<Object> getPurchasesJsonList() {
      return purchasesJsonList;
    }

    public void setPurchasesJsonList(@NonNull List<Object> setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"purchasesJsonList\" is null.");
      }
      this.purchasesJsonList = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformPurchasesResponse() {}

    public static final class Builder {

      private @Nullable PlatformBillingResult billingResult;

      @CanIgnoreReturnValue
      public @NonNull Builder setBillingResult(@NonNull PlatformBillingResult setterArg) {
        this.billingResult = setterArg;
        return this;
      }

      private @Nullable List<Object> purchasesJsonList;

      @CanIgnoreReturnValue
      public @NonNull Builder setPurchasesJsonList(@NonNull List<Object> setterArg) {
        this.purchasesJsonList = setterArg;
        return this;
      }

      public @NonNull PlatformPurchasesResponse build() {
        PlatformPurchasesResponse pigeonReturn = new PlatformPurchasesResponse();
        pigeonReturn.setBillingResult(billingResult);
        pigeonReturn.setPurchasesJsonList(purchasesJsonList);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(2);
      toListResult.add((billingResult == null) ? null : billingResult.toList());
      toListResult.add(purchasesJsonList);
      return toListResult;
    }

    static @NonNull PlatformPurchasesResponse fromList(@NonNull ArrayList<Object> list) {
      PlatformPurchasesResponse pigeonResult = new PlatformPurchasesResponse();
      Object billingResult = list.get(0);
      pigeonResult.setBillingResult(
          (billingResult == null)
              ? null
              : PlatformBillingResult.fromList((ArrayList<Object>) billingResult));
      Object purchasesJsonList = list.get(1);
      pigeonResult.setPurchasesJsonList((List<Object>) purchasesJsonList);
      return pigeonResult;
    }
  }

  /**
   * Pigeon version of UserChoiceDetailsWrapper and Java UserChoiceDetails.
   *
   * <p>Generated class from Pigeon that represents data sent in messages.
   */
  public static final class PlatformUserChoiceDetails {
    private @Nullable String originalExternalTransactionId;

    public @Nullable String getOriginalExternalTransactionId() {
      return originalExternalTransactionId;
    }

    public void setOriginalExternalTransactionId(@Nullable String setterArg) {
      this.originalExternalTransactionId = setterArg;
    }

    private @NonNull String externalTransactionToken;

    public @NonNull String getExternalTransactionToken() {
      return externalTransactionToken;
    }

    public void setExternalTransactionToken(@NonNull String setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"externalTransactionToken\" is null.");
      }
      this.externalTransactionToken = setterArg;
    }

    /**
     * A JSON-compatible list of products, where each entry in the list is a Map<String, Object?>
     * JSON encoding of the product.
     */
    private @NonNull List<Object> productsJsonList;

    public @NonNull List<Object> getProductsJsonList() {
      return productsJsonList;
    }

    public void setProductsJsonList(@NonNull List<Object> setterArg) {
      if (setterArg == null) {
        throw new IllegalStateException("Nonnull field \"productsJsonList\" is null.");
      }
      this.productsJsonList = setterArg;
    }

    /** Constructor is non-public to enforce null safety; use Builder. */
    PlatformUserChoiceDetails() {}

    public static final class Builder {

      private @Nullable String originalExternalTransactionId;

      @CanIgnoreReturnValue
      public @NonNull Builder setOriginalExternalTransactionId(@Nullable String setterArg) {
        this.originalExternalTransactionId = setterArg;
        return this;
      }

      private @Nullable String externalTransactionToken;

      @CanIgnoreReturnValue
      public @NonNull Builder setExternalTransactionToken(@NonNull String setterArg) {
        this.externalTransactionToken = setterArg;
        return this;
      }

      private @Nullable List<Object> productsJsonList;

      @CanIgnoreReturnValue
      public @NonNull Builder setProductsJsonList(@NonNull List<Object> setterArg) {
        this.productsJsonList = setterArg;
        return this;
      }

      public @NonNull PlatformUserChoiceDetails build() {
        PlatformUserChoiceDetails pigeonReturn = new PlatformUserChoiceDetails();
        pigeonReturn.setOriginalExternalTransactionId(originalExternalTransactionId);
        pigeonReturn.setExternalTransactionToken(externalTransactionToken);
        pigeonReturn.setProductsJsonList(productsJsonList);
        return pigeonReturn;
      }
    }

    @NonNull
    ArrayList<Object> toList() {
      ArrayList<Object> toListResult = new ArrayList<Object>(3);
      toListResult.add(originalExternalTransactionId);
      toListResult.add(externalTransactionToken);
      toListResult.add(productsJsonList);
      return toListResult;
    }

    static @NonNull PlatformUserChoiceDetails fromList(@NonNull ArrayList<Object> list) {
      PlatformUserChoiceDetails pigeonResult = new PlatformUserChoiceDetails();
      Object originalExternalTransactionId = list.get(0);
      pigeonResult.setOriginalExternalTransactionId((String) originalExternalTransactionId);
      Object externalTransactionToken = list.get(1);
      pigeonResult.setExternalTransactionToken((String) externalTransactionToken);
      Object productsJsonList = list.get(2);
      pigeonResult.setProductsJsonList((List<Object>) productsJsonList);
      return pigeonResult;
    }
  }

  /** Asynchronous error handling return type for non-nullable API method returns. */
  public interface Result<T> {
    /** Success case callback method for handling returns. */
    void success(@NonNull T result);

    /** Failure case callback method for handling errors. */
    void error(@NonNull Throwable error);
  }
  /** Asynchronous error handling return type for nullable API method returns. */
  public interface NullableResult<T> {
    /** Success case callback method for handling returns. */
    void success(@Nullable T result);

    /** Failure case callback method for handling errors. */
    void error(@NonNull Throwable error);
  }
  /** Asynchronous error handling return type for void API method returns. */
  public interface VoidResult {
    /** Success case callback method for handling returns. */
    void success();

    /** Failure case callback method for handling errors. */
    void error(@NonNull Throwable error);
  }

  private static class InAppPurchaseApiCodec extends StandardMessageCodec {
    public static final InAppPurchaseApiCodec INSTANCE = new InAppPurchaseApiCodec();

    private InAppPurchaseApiCodec() {}

    @Override
    protected Object readValueOfType(byte type, @NonNull ByteBuffer buffer) {
      switch (type) {
        case (byte) 128:
          return PlatformAlternativeBillingOnlyReportingDetailsResponse.fromList(
              (ArrayList<Object>) readValue(buffer));
        case (byte) 129:
          return PlatformBillingConfigResponse.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 130:
          return PlatformBillingFlowParams.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 131:
          return PlatformBillingResult.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 132:
          return PlatformProduct.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 133:
          return PlatformProductDetailsResponse.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 134:
          return PlatformPurchaseHistoryResponse.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 135:
          return PlatformPurchasesResponse.fromList((ArrayList<Object>) readValue(buffer));
        default:
          return super.readValueOfType(type, buffer);
      }
    }

    @Override
    protected void writeValue(@NonNull ByteArrayOutputStream stream, Object value) {
      if (value instanceof PlatformAlternativeBillingOnlyReportingDetailsResponse) {
        stream.write(128);
        writeValue(
            stream, ((PlatformAlternativeBillingOnlyReportingDetailsResponse) value).toList());
      } else if (value instanceof PlatformBillingConfigResponse) {
        stream.write(129);
        writeValue(stream, ((PlatformBillingConfigResponse) value).toList());
      } else if (value instanceof PlatformBillingFlowParams) {
        stream.write(130);
        writeValue(stream, ((PlatformBillingFlowParams) value).toList());
      } else if (value instanceof PlatformBillingResult) {
        stream.write(131);
        writeValue(stream, ((PlatformBillingResult) value).toList());
      } else if (value instanceof PlatformProduct) {
        stream.write(132);
        writeValue(stream, ((PlatformProduct) value).toList());
      } else if (value instanceof PlatformProductDetailsResponse) {
        stream.write(133);
        writeValue(stream, ((PlatformProductDetailsResponse) value).toList());
      } else if (value instanceof PlatformPurchaseHistoryResponse) {
        stream.write(134);
        writeValue(stream, ((PlatformPurchaseHistoryResponse) value).toList());
      } else if (value instanceof PlatformPurchasesResponse) {
        stream.write(135);
        writeValue(stream, ((PlatformPurchasesResponse) value).toList());
      } else {
        super.writeValue(stream, value);
      }
    }
  }

  /** Generated interface from Pigeon that represents a handler of messages from Flutter. */
  public interface InAppPurchaseApi {
    /** Wraps BillingClient#isReady. */
    @NonNull
    Boolean isReady();
    /** Wraps BillingClient#startConnection(BillingClientStateListener). */
    void startConnection(
        @NonNull Long callbackHandle,
        @NonNull PlatformBillingChoiceMode billingMode,
        @NonNull Result<PlatformBillingResult> result);
    /** Wraps BillingClient#endConnection(BillingClientStateListener). */
    void endConnection();
    /**
     * Wraps BillingClient#getBillingConfigAsync(GetBillingConfigParams,
     * BillingConfigResponseListener).
     */
    void getBillingConfigAsync(@NonNull Result<PlatformBillingConfigResponse> result);
    /** Wraps BillingClient#launchBillingFlow(Activity, BillingFlowParams). */
    @NonNull
    PlatformBillingResult launchBillingFlow(@NonNull PlatformBillingFlowParams params);
    /**
     * Wraps BillingClient#acknowledgePurchase(AcknowledgePurchaseParams,
     * AcknowledgePurchaseResponseListener).
     */
    void acknowledgePurchase(
        @NonNull String purchaseToken, @NonNull Result<PlatformBillingResult> result);
    /** Wraps BillingClient#consumeAsync(ConsumeParams, ConsumeResponseListener). */
    void consumeAsync(@NonNull String purchaseToken, @NonNull Result<PlatformBillingResult> result);
    /** Wraps BillingClient#queryPurchasesAsync(QueryPurchaseParams, PurchaseResponseListener). */
    void queryPurchasesAsync(
        @NonNull PlatformProductType productType,
        @NonNull Result<PlatformPurchasesResponse> result);
    /**
     * Wraps BillingClient#queryPurchaseHistoryAsync(QueryPurchaseHistoryParams,
     * PurchaseHistoryResponseListener).
     */
    void queryPurchaseHistoryAsync(
        @NonNull PlatformProductType productType,
        @NonNull Result<PlatformPurchaseHistoryResponse> result);
    /**
     * Wraps BillingClient#queryProductDetailsAsync(QueryProductDetailsParams,
     * ProductDetailsResponseListener).
     */
    void queryProductDetailsAsync(
        @NonNull List<PlatformProduct> products,
        @NonNull Result<PlatformProductDetailsResponse> result);
    /** Wraps BillingClient#isFeatureSupported(String). */
    @NonNull
    Boolean isFeatureSupported(@NonNull String feature);
    /** Wraps BillingClient#isAlternativeBillingOnlyAvailableAsync(). */
    void isAlternativeBillingOnlyAvailableAsync(@NonNull Result<PlatformBillingResult> result);
    /** Wraps BillingClient#showAlternativeBillingOnlyInformationDialog(). */
    void showAlternativeBillingOnlyInformationDialog(@NonNull Result<PlatformBillingResult> result);
    /**
     * Wraps
     * BillingClient#createAlternativeBillingOnlyReportingDetailsAsync(AlternativeBillingOnlyReportingDetailsListener).
     */
    void createAlternativeBillingOnlyReportingDetailsAsync(
        @NonNull Result<PlatformAlternativeBillingOnlyReportingDetailsResponse> result);

    /** The codec used by InAppPurchaseApi. */
    static @NonNull MessageCodec<Object> getCodec() {
      return InAppPurchaseApiCodec.INSTANCE;
    }
    /**
     * Sets up an instance of `InAppPurchaseApi` to handle messages through the `binaryMessenger`.
     */
    static void setUp(@NonNull BinaryMessenger binaryMessenger, @Nullable InAppPurchaseApi api) {
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.isReady",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                try {
                  Boolean output = api.isReady();
                  wrapped.add(0, output);
                } catch (Throwable exception) {
                  ArrayList<Object> wrappedError = wrapError(exception);
                  wrapped = wrappedError;
                }
                reply.reply(wrapped);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.startConnection",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                Number callbackHandleArg = (Number) args.get(0);
                PlatformBillingChoiceMode billingModeArg =
                    PlatformBillingChoiceMode.values()[(int) args.get(1)];
                Result<PlatformBillingResult> resultCallback =
                    new Result<PlatformBillingResult>() {
                      public void success(PlatformBillingResult result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.startConnection(
                    (callbackHandleArg == null) ? null : callbackHandleArg.longValue(),
                    billingModeArg,
                    resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.endConnection",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                try {
                  api.endConnection();
                  wrapped.add(0, null);
                } catch (Throwable exception) {
                  ArrayList<Object> wrappedError = wrapError(exception);
                  wrapped = wrappedError;
                }
                reply.reply(wrapped);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.getBillingConfigAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                Result<PlatformBillingConfigResponse> resultCallback =
                    new Result<PlatformBillingConfigResponse>() {
                      public void success(PlatformBillingConfigResponse result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.getBillingConfigAsync(resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.launchBillingFlow",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                PlatformBillingFlowParams paramsArg = (PlatformBillingFlowParams) args.get(0);
                try {
                  PlatformBillingResult output = api.launchBillingFlow(paramsArg);
                  wrapped.add(0, output);
                } catch (Throwable exception) {
                  ArrayList<Object> wrappedError = wrapError(exception);
                  wrapped = wrappedError;
                }
                reply.reply(wrapped);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.acknowledgePurchase",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                String purchaseTokenArg = (String) args.get(0);
                Result<PlatformBillingResult> resultCallback =
                    new Result<PlatformBillingResult>() {
                      public void success(PlatformBillingResult result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.acknowledgePurchase(purchaseTokenArg, resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.consumeAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                String purchaseTokenArg = (String) args.get(0);
                Result<PlatformBillingResult> resultCallback =
                    new Result<PlatformBillingResult>() {
                      public void success(PlatformBillingResult result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.consumeAsync(purchaseTokenArg, resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.queryPurchasesAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                PlatformProductType productTypeArg =
                    PlatformProductType.values()[(int) args.get(0)];
                Result<PlatformPurchasesResponse> resultCallback =
                    new Result<PlatformPurchasesResponse>() {
                      public void success(PlatformPurchasesResponse result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.queryPurchasesAsync(productTypeArg, resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.queryPurchaseHistoryAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                PlatformProductType productTypeArg =
                    PlatformProductType.values()[(int) args.get(0)];
                Result<PlatformPurchaseHistoryResponse> resultCallback =
                    new Result<PlatformPurchaseHistoryResponse>() {
                      public void success(PlatformPurchaseHistoryResponse result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.queryPurchaseHistoryAsync(productTypeArg, resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.queryProductDetailsAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                List<PlatformProduct> productsArg = (List<PlatformProduct>) args.get(0);
                Result<PlatformProductDetailsResponse> resultCallback =
                    new Result<PlatformProductDetailsResponse>() {
                      public void success(PlatformProductDetailsResponse result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.queryProductDetailsAsync(productsArg, resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.isFeatureSupported",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                ArrayList<Object> args = (ArrayList<Object>) message;
                String featureArg = (String) args.get(0);
                try {
                  Boolean output = api.isFeatureSupported(featureArg);
                  wrapped.add(0, output);
                } catch (Throwable exception) {
                  ArrayList<Object> wrappedError = wrapError(exception);
                  wrapped = wrappedError;
                }
                reply.reply(wrapped);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.isAlternativeBillingOnlyAvailableAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                Result<PlatformBillingResult> resultCallback =
                    new Result<PlatformBillingResult>() {
                      public void success(PlatformBillingResult result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.isAlternativeBillingOnlyAvailableAsync(resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.showAlternativeBillingOnlyInformationDialog",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                Result<PlatformBillingResult> resultCallback =
                    new Result<PlatformBillingResult>() {
                      public void success(PlatformBillingResult result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.showAlternativeBillingOnlyInformationDialog(resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
      {
        BasicMessageChannel<Object> channel =
            new BasicMessageChannel<>(
                binaryMessenger,
                "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseApi.createAlternativeBillingOnlyReportingDetailsAsync",
                getCodec());
        if (api != null) {
          channel.setMessageHandler(
              (message, reply) -> {
                ArrayList<Object> wrapped = new ArrayList<Object>();
                Result<PlatformAlternativeBillingOnlyReportingDetailsResponse> resultCallback =
                    new Result<PlatformAlternativeBillingOnlyReportingDetailsResponse>() {
                      public void success(
                          PlatformAlternativeBillingOnlyReportingDetailsResponse result) {
                        wrapped.add(0, result);
                        reply.reply(wrapped);
                      }

                      public void error(Throwable error) {
                        ArrayList<Object> wrappedError = wrapError(error);
                        reply.reply(wrappedError);
                      }
                    };

                api.createAlternativeBillingOnlyReportingDetailsAsync(resultCallback);
              });
        } else {
          channel.setMessageHandler(null);
        }
      }
    }
  }

  private static class InAppPurchaseCallbackApiCodec extends StandardMessageCodec {
    public static final InAppPurchaseCallbackApiCodec INSTANCE =
        new InAppPurchaseCallbackApiCodec();

    private InAppPurchaseCallbackApiCodec() {}

    @Override
    protected Object readValueOfType(byte type, @NonNull ByteBuffer buffer) {
      switch (type) {
        case (byte) 128:
          return PlatformBillingResult.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 129:
          return PlatformPurchasesResponse.fromList((ArrayList<Object>) readValue(buffer));
        case (byte) 130:
          return PlatformUserChoiceDetails.fromList((ArrayList<Object>) readValue(buffer));
        default:
          return super.readValueOfType(type, buffer);
      }
    }

    @Override
    protected void writeValue(@NonNull ByteArrayOutputStream stream, Object value) {
      if (value instanceof PlatformBillingResult) {
        stream.write(128);
        writeValue(stream, ((PlatformBillingResult) value).toList());
      } else if (value instanceof PlatformPurchasesResponse) {
        stream.write(129);
        writeValue(stream, ((PlatformPurchasesResponse) value).toList());
      } else if (value instanceof PlatformUserChoiceDetails) {
        stream.write(130);
        writeValue(stream, ((PlatformUserChoiceDetails) value).toList());
      } else {
        super.writeValue(stream, value);
      }
    }
  }

  /** Generated class from Pigeon that represents Flutter messages that can be called from Java. */
  public static class InAppPurchaseCallbackApi {
    private final @NonNull BinaryMessenger binaryMessenger;

    public InAppPurchaseCallbackApi(@NonNull BinaryMessenger argBinaryMessenger) {
      this.binaryMessenger = argBinaryMessenger;
    }

    /** Public interface for sending reply. */
    /** The codec used by InAppPurchaseCallbackApi. */
    static @NonNull MessageCodec<Object> getCodec() {
      return InAppPurchaseCallbackApiCodec.INSTANCE;
    }
    /** Called for BillingClientStateListener#onBillingServiceDisconnected(). */
    public void onBillingServiceDisconnected(
        @NonNull Long callbackHandleArg, @NonNull VoidResult result) {
      final String channelName =
          "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseCallbackApi.onBillingServiceDisconnected";
      BasicMessageChannel<Object> channel =
          new BasicMessageChannel<>(binaryMessenger, channelName, getCodec());
      channel.send(
          new ArrayList<Object>(Collections.singletonList(callbackHandleArg)),
          channelReply -> {
            if (channelReply instanceof List) {
              List<Object> listReply = (List<Object>) channelReply;
              if (listReply.size() > 1) {
                result.error(
                    new FlutterError(
                        (String) listReply.get(0),
                        (String) listReply.get(1),
                        (String) listReply.get(2)));
              } else {
                result.success();
              }
            } else {
              result.error(createConnectionError(channelName));
            }
          });
    }
    /** Called for PurchasesUpdatedListener#onPurchasesUpdated(BillingResult, List<Purchase>). */
    public void onPurchasesUpdated(
        @NonNull PlatformPurchasesResponse updateArg, @NonNull VoidResult result) {
      final String channelName =
          "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseCallbackApi.onPurchasesUpdated";
      BasicMessageChannel<Object> channel =
          new BasicMessageChannel<>(binaryMessenger, channelName, getCodec());
      channel.send(
          new ArrayList<Object>(Collections.singletonList(updateArg)),
          channelReply -> {
            if (channelReply instanceof List) {
              List<Object> listReply = (List<Object>) channelReply;
              if (listReply.size() > 1) {
                result.error(
                    new FlutterError(
                        (String) listReply.get(0),
                        (String) listReply.get(1),
                        (String) listReply.get(2)));
              } else {
                result.success();
              }
            } else {
              result.error(createConnectionError(channelName));
            }
          });
    }
    /** Called for UserChoiceBillingListener#userSelectedAlternativeBilling(UserChoiceDetails). */
    public void userSelectedalternativeBilling(
        @NonNull PlatformUserChoiceDetails detailsArg, @NonNull VoidResult result) {
      final String channelName =
          "dev.flutter.pigeon.in_app_purchase_android.InAppPurchaseCallbackApi.userSelectedalternativeBilling";
      BasicMessageChannel<Object> channel =
          new BasicMessageChannel<>(binaryMessenger, channelName, getCodec());
      channel.send(
          new ArrayList<Object>(Collections.singletonList(detailsArg)),
          channelReply -> {
            if (channelReply instanceof List) {
              List<Object> listReply = (List<Object>) channelReply;
              if (listReply.size() > 1) {
                result.error(
                    new FlutterError(
                        (String) listReply.get(0),
                        (String) listReply.get(1),
                        (String) listReply.get(2)));
              } else {
                result.success();
              }
            } else {
              result.error(createConnectionError(channelName));
            }
          });
    }
  }
}
